@@ -223,6 +223,9 @@ async def fetch_premade_statistics(item_ids) -> None:
                 else:
                     day["item_id"] = hashlib.md5(item_name.encode()).hexdigest()
 
+        with open(os.path.join('output', date), 'w') as f:
+            json.dump(data, f)
+
     async with cache_manager() as cache:
         async with session_manager() as session:
             date_list = await get_dates_to_fetch(cache, session)
